# Changelog

<!--next-version-placeholder-->

## v0.5.0 (2023-01-22)
### Feature
* Slice_dataframe, add a support of arrays ([#13](https://github.com/avolok/spalah/issues/13)) ([`de80906`](https://github.com/avolok/spalah/commit/de8090680916081956f95d41c2585b0877a8dbbd))

## v0.4.1 (2022-10-11)
### Fix
* Rename *_delta_properties methods ([#12](https://github.com/avolok/spalah/issues/12)) ([`52ec3f9`](https://github.com/avolok/spalah/commit/52ec3f9bc446d7ef33b67713769ba6563ee55a07))

## v0.4.0 (2022-10-02)
### Feature
* Add a 'datalake' module ([#11](https://github.com/avolok/spalah/issues/11)) ([`c326926`](https://github.com/avolok/spalah/commit/c3269260a646a9d2297028d1c1d4c871deb67093))

## v0.3.1 (2022-08-05)
### Fix
* Script_dataframe, change default value ([#8](https://github.com/avolok/spalah/issues/8)) ([`3608dc3`](https://github.com/avolok/spalah/commit/3608dc3143f0a708c4c3d4d0b95c903f46246a6c))

### Documentation
* Add exampe of use for flatten_schema ([`b50744c`](https://github.com/avolok/spalah/commit/b50744c4f6a3db6c9b6a0af2aecd0773e9b65c09))
* Add readme for SchemaComparer ([`bfc86e0`](https://github.com/avolok/spalah/commit/bfc86e071a412e2bfedd0e30a08d877e60cfb6e3))

## v0.3.0 (2022-07-17)
### Feature
* Add SchemaComparer ([`214fe4d`](https://github.com/avolok/spalah/commit/214fe4d9d7b8656181cb50d674f17cbd045bdf6b))

### Fix
* Slice_dataframe filtering logic ([`6926c98`](https://github.com/avolok/spalah/commit/6926c983e692ecb25cd8b812066acf176db65753))
* Slice_dataframe changed default prm values ([`4d9fe91`](https://github.com/avolok/spalah/commit/4d9fe916b1b08d7660763d8f95d64ffa9188890d))

## v0.2.0 (2022-07-11)
### Feature
* flatten_schema - add include_datatype ([`68d4c71`](https://github.com/avolok/spalah/commit/68d4c71e99156c00ffe99b20d1d2cb90945b30a2))

## v0.1.0 (2022-07-10)
### Feature
* Initial code commit ([`844616f`](https://github.com/avolok/spalah/commit/844616ffb6ab89ab31c97644d74943bf9c15070e))

### Fix
* Downgrade of version to fix psr release ([#2](https://github.com/avolok/spalah/issues/2)) ([`e5b470c`](https://github.com/avolok/spalah/commit/e5b470c1379e285c0603fed5d3dcd489314469e1))

## v0.1.0 (2022-07-09)
### Feature
* Initial commit
